from .registration_view import RegistrationView  # noqa
from .logout_view import LogoutView, logout_view  # noqa
from .obtain_auth_token import ObtainAuthToken, obtain_auth_token  # noqa
from .refresh_token_view import RefreshTokenView, refresh_token_view  # noqa
from .login_views import LogoutView, LoginView  # noqa

from .email_confirmation_view import EmailConfirmationView, EmailConfirmationLinkView  # noqa
from .phone_confirmation_view import PhoneConfirmationView  # noqa
from .restore_password_view import RestorePasswordView # noqa
from .change_password_view import ChangePasswordView # noqa
