GARPIX_USER_SETTINGS = {
    # base settings
    'USE_REFERRAL_LINKS': False,
    'REFERRAL_REDIRECT_URL': '/',
    # email/phone confirmation
    'USE_EMAIL_CONFIRMATION': False,
    'USE_PHONE_CONFIRMATION': False,
    'USE_PREREGISTRATION_EMAIL_CONFIRMATION': False,
    'USE_PREREGISTRATION_PHONE_CONFIRMATION': False,
    'USE_EMAIL_LINK_CONFIRMATION': False,
    # restore password
    'USE_RESTORE_PASSWORD': True
}

GARPIX_USER_CONFIRMATION_SETTINGS = {
    'USE_EMAIL_CONFIRMATION': True,
    'USE_PHONE_CONFIRMATION': True,
    'USE_PREREGISTRATION_EMAIL_CONFIRMATION': True,
    'USE_PREREGISTRATION_PHONE_CONFIRMATION': True,
    'USE_EMAIL_LINK_CONFIRMATION': False
}
